Features
********


This section describes all features that are shipped with this package.

Scenario Features
=================

.. autoclass:: balderhub.selenium.lib.scenario_features.SeleniumFeature
    :members:

.. autoclass:: balderhub.selenium.lib.scenario_features.SeleniumProxy
    :members:


Setup Features
==============

.. autoclass:: balderhub.selenium.lib.setup_features.SeleniumChromeWebdriverFeature
    :members:

.. autoclass:: balderhub.selenium.lib.setup_features.SeleniumEdgeWebdriverFeature
    :members:

.. autoclass:: balderhub.selenium.lib.setup_features.SeleniumFirefoxWebdriverFeature
    :members:

.. autoclass:: balderhub.selenium.lib.setup_features.SeleniumIeWebdriverFeature
    :members:

.. autoclass:: balderhub.selenium.lib.setup_features.SeleniumRemoteWebdriverFeature
    :members:

.. autoclass:: balderhub.selenium.lib.setup_features.SeleniumSafariWebdriverFeature
    :members:
